@@ -126,21 +126,15 @@ class powerswitch:
         return self.status(outlet) != 'ON'
     def cycle(self,outlet=0):
         """ Cycle power to an outlet 
-            False = Success
-            True = Fail
+            False = Power off Success
+            True = Power off Fail
+            Note, does not return any status info about the power on part of the operation by design
         """        
-        start_status=self.status(outlet)
-        if start_status == 'OFF':
-          return False
-        if start_status == 'Unknown':
+        if self.off(outlet):
           return True
-        else:
-          if self.off(outlet):
-            return True
-          time.sleep(self.cycletime)
-          if self.on(outlet):
-            return True
-        return self.status(outlet) != start_status
+        time.sleep(self.cycletime)
+        self.on(outlet):
+        return False
     def statuslist(self):
         """ Return the status of all outlets in a list, 
         each item will contain 3 items plugnumber, hostname and state  """
